# Topsis-Dhaval-101917169
It calculates topsis score.

## Installation
```pip install Topsis_Dhaval_101917169 {your input file name} {weights} {impacts} {output file name}```

## How to use it?
Give input csv file name, weights follwed by impacts by command line.